@@ -75,20 +75,20 @@ def findlinestarts(code, dup_lines=False):
 
     lastlineno = None
     lineno = code.co_firstlineno
-    addr = 0
+    offset = 0
     for byte_incr, line_incr in zip(byte_increments, line_increments):
         if byte_incr:
             if (lineno != lastlineno or
                 (dup_lines and 0 < byte_incr < 255)):
-                yield (addr, lineno)
+                yield (offset, lineno)
                 lastlineno = lineno
                 pass
-            addr += byte_incr
+            offset += byte_incr
             pass
         lineno += line_incr
     if (lineno != lastlineno or
         (dup_lines and 0 < byte_incr < 255)):
-        yield (addr, lineno)
+        yield (offset, lineno)
 
 def offset2line(offset, linestarts):
     """linestarts is expected to be a *list) of (offset, line number)
